#!/usr/bin/env python

import json
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "analysis_software_version": "fastp version number",
    "hid": "historic ID for fastp file from galaxy",
    "reference_database_version": "DB version",
    "trimmed_forward_R1_path": "forward R1 trimmed file",
    "trimmed_forward_R1_hid": "historic ID for forward reads file from galaxy",
    "trimmed_reverse_R2_path": "reverse R2 trimmed file",
    "trimmed_reverse_R2_hid": "historic ID for reverse reads file from galaxy",
    "html_report_path": "html fastp report path",
    "html_report_hid": "historic ID for fastp html report",
}


class FastpIterator(AbromicsResultIterator):
    """Fastp tool parser
    Filter results from fastp json file
    Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "fastp"
        self.metadata = metadata
        super().__init__(source, self.metadata)
        self.abromics_results["tool_has_database"] = False
        self.parse()

    def parse(self):
        """Read json output file from fastp trimming"""
        if not self.stream == 0:
            fastp_json_object = json.loads(self.stream.read())
            self.abromics_results[
                "analysis_software_version"
                ] = fastp_json_object[
                "summary"
            ].pop("fastp_version")
            self.abromics_results["results"][0]["content"].append(
                fastp_json_object
                )
        self.extract_metadata_information(self.metadata)
