#!/usr/bin/env python
import pandas as pd
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "hid": "historic ID for integronfinder file from galaxy",
    "analysis_software_version": "integronfinder version",
    "reference_database_version": "DB version",
    "summary_file_path": "integronfinder summary file path",
    "summary_file_hid": "historic ID for summary file from galaxy",
}


class IntegronFinderIterator(AbromicsResultIterator):
    """IntegronFinder2 tool parser
    Filter results from integrons file
    Could also filter file for:
    summary file
    Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "integronfinder2"
        self.metadata = metadata
        super().__init__(source, self.metadata)
        self.abromics_results["tool_has_database"] = False
        self.parse()

    def parse(self):
        """Build a dictionnary from integronfinder results
        Integrons and summary file could be analyzed
        """
        if not self.stream == 0:
            integron_df = pd.read_table(self.stream, header=1)
            integron_df.fillna("", inplace=True)
            integron_json = integron_df.to_dict(orient="records")
            self.abromics_results["results"][0]["content"] = integron_json

        if self.metadata["summary_file_path"]:
            self._check_input_files(self.abromics_results["summary_file_path"])
            summary_df = pd.read_table(self.stream, header=1)
            summary_json = summary_df.to_dict(orient="records")
            self.abromics_results["results"].append(
                {
                    "name": "summary",
                    "file_path": self.abromics_results.pop(
                        "summary_file_path"
                        ),
                    "hid": self.abromics_results.pop("summary_file_hid"),
                    "galaxy_id": "",
                    "content": summary_json
                    }
            )
        else:
            self.abromics_results["results"].append(
                {
                    "name": "summary",
                    "file_path": self.abromics_results.pop(
                        "summary_file_path"
                        ),
                    "hid": self.abromics_results.pop("summary_file_hid"),
                    "galaxy_id": "",
                    "content": []
                    }
            )
