#!/usr/bin/env python

import pandas as pd
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "hid": "Historic ID to quast file from Galaxy",
    "reference_database_version": "DB version",
    "analysis_software_version": "Quast version number",
    "quast_html_path": "Quast html report file",
    "quast_html_hid": "Historic ID to quast html file from Galaxy"
}


class QuastIterator(AbromicsResultIterator):
    """Quast tool parser
    Extract information from quast tabular results
    Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "quast"
        self.metadata = metadata
        super().__init__(source, self.metadata)
        self.abromics_results["tool_has_database"] = False
        self.parse()

    def parse(self):
        """Parse Quast tabular file"""
        if not self.stream == 0:
            reader = pd.read_table(
                self.source,
                delimiter="\t",
                header=None,
                index_col=False,
            )
            reader[0] = reader[0].replace({r"# ": ""}, regex=True)
            reader[0] = reader[0].replace({r" ": "_"}, regex=True)
            reader[0] = reader[0].replace({r"_\(\%\)": ""}, regex=True)
            reader[0] = reader[0].replace({r"^\s": ""}, regex=True)
            reader[0] = reader[0].replace({r"\s": "_"}, regex=True)
            ziped_values = zip(reader[0], reader[1])
            ziped_values = dict(ziped_values)
            self.abromics_results["results"][0]["content"].append(ziped_values)
        self.extract_metadata_information(self.metadata)
