#!/usr/bin/env python
import json
import pandas as pd
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "hid": "Historic ID to refseq result from Galaxy",
    "reference_database_version": "DB version",
    "analysis_software_version": "refseqmasher version number",
}


class RefseqmasherIterator(AbromicsResultIterator):
    """Refseqmasher tool parser
    Filter results from refseq tabular file
    Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "refseqmasher"
        self.metadata = metadata
        super().__init__(source, metadata)
        self.abromics_results["tool_has_database"] = False
        if not self.stream == 0:
            self.parse()

    def parse(self):
        """Refseqmasher matches parser"""
        refseq_df = pd.read_table(self.source)
        refseq_json = refseq_df.to_json(
            orient="records",
        )
        self.abromics_results["results"][0][
            "content"
            ] = json.loads(refseq_json)
