#!/usr/bin/env python
import json
import pandas as pd
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "hid": "Historic ID provided by Galaxy for tabular file",
    "analysis_software_name": "Tool name to the input file",
    "reference_database_version": "DB version",
    "analysis_software_version": "Software version to the input file",
}


class GenericTabularIterator(AbromicsResultIterator):
    """Generic tool parser for tabular files
    Parse tabular file using generic options
    Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """

    def __init__(self, source, metadata):
        self.metadata = metadata
        super().__init__(source, self.metadata)
        self.abromics_results["tool_has_database"] = False
        if not self.stream == 0:
            self.parse()

    def parse(self):
        """Parse tabular dataframe with header"""
        # skip any manually specified fields for later
        reader = self._filter_dataframe_type(self.stream)
        if self.abromics_results["analysis_software_name"]:
            pass
        else:
            self.abromics_results["analysis_software_name"] = "tabular_file"
        self.abromics_results["results"][0]["content"] = reader

    def _filter_dataframe_type(
        self,
        handle,
        header_position=0,
        separator="\t",
        orient_type="records",
    ):
        reader = pd.read_table(
            handle,
            header=header_position,
            sep=separator,
        )
        reader = reader.replace("^[ \t]+", "", regex=True)
        reader = reader.replace("[.]$", "", regex=True)
        reader = reader.replace(" ", "", regex=True)
        reader = json.loads(reader.to_json(orient=orient_type))
        return reader
